@@ -2,23 +2,45 @@
 #'
 #' Format for converting from R Markdown to GitHub Flavored Markdown.
 #'
-#' See the \href{https://rmarkdown.rstudio.com/github_document_format.html}{online
-#' documentation} for additional details on using the \code{github_document}
+#' See the [online
+#' documentation](https://rmarkdown.rstudio.com/github_document_format.html) for additional details on using the `github_document()`
 #' format.
 #' @inheritParams output_format
 #' @inheritParams html_document
 #' @inheritParams md_document
-#' @param hard_line_breaks \code{TRUE} to generate markdown that uses a simple
+#' @param math_method `"webtex"` (the default) is used to render equations. This
+#'   will insert math an image in the resulting Markdown. See [html_document()]
+#'   for option to change webtex URL. Set to `NULL` to opt-out.
+#' @param hard_line_breaks `TRUE` to generate markdown that uses a simple
 #'   newline to represent a line break (as opposed to two-spaces and a newline).
-#' @param html_preview \code{TRUE} to also generate an HTML file for the purpose of
+#' @param html_preview `TRUE` to also generate an HTML file for the purpose of
 #'   locally previewing what the document will look like on GitHub.
-#' @param keep_html \code{TRUE} to keep the preview HTML file in the working
-#'   directory. Default is \code{FALSE}.
-#' @return R Markdown output format to pass to \code{\link{render}}
+#' @param keep_html `TRUE` to keep the preview HTML file in the working
+#'   directory. Default is `FALSE`.
+#'
+#' @details # About Math support
+#'
+#' For Github Markdown output, PNG images with a white background are used so
+#' that it shows correctly on Github on both light and dark theme. You can
+#' choose to only output SVG for better quality by changing the URL used:
+#'
+#' ```yaml
+#' output:
+#'   github_document:
+#'     math_method:
+#'       engine: webtex
+#'       url: https://latex.codecogs.com/svg.image?
+#' ```
+#'
+#' Background or fonts color cannot be changed for now and your equation may not be visible on dark theme.
+#' @return R Markdown output format to pass to [render()]
 #' @export
+#' @md
 github_document <- function(toc = FALSE,
                             toc_depth = 3,
                             number_sections = FALSE,
+                            math_method = "webtex",
+                            preserve_yaml = FALSE,
                             fig_width = 7,
                             fig_height = 5,
                             dev = 'png',
@@ -52,22 +74,40 @@ github_document <- function(toc = FALSE,
     "--atx-headers", pandoc_args
   )
 
-  if (toc && !isTRUE(grepl("gfm_auto_identifiers", md_extensions))) {
+  if ((toc || number_sections) && !isTRUE(grepl("gfm_auto_identifiers", md_extensions))) {
     md_extensions <- c(md_extensions, "+gfm_auto_identifiers")
   }
 
+  # math support
+  if (!is.null(math_method)) {
+    math <- check_math_argument(math_method)
+    if (math$engine != "webtex") {
+      stop("Markdown output format only support 'webtex' for math engine")
+    }
+    if (is.null(math$url)) {
+      # default to png and white background
+      math$url <- "https://latex.codecogs.com/png.image?%5Cdpi%7B110%7D&space;%5Cbg_white&space;"
+    }
+    math <- add_math_support(math, NULL, NULL, NULL)
+    pandoc_args <- c(pandoc_args, math$args)
+  }
+
   format <- md_document(
     variant = variant, toc = toc, toc_depth = toc_depth,
-    number_sections = number_sections, fig_width = fig_width,
-    fig_height = fig_height, dev = dev, df_print = df_print,
-    includes = includes, md_extensions = md_extensions,
-    pandoc_args = pandoc_args
+    number_sections = number_sections, preserve_yaml = preserve_yaml,
+    fig_width = fig_width, fig_height = fig_height,
+    dev = dev, df_print = df_print, includes = includes,
+    md_extensions = md_extensions, pandoc_args = pandoc_args
   )
 
   # add a post processor for generating a preview if requested
-  if (html_preview) {
-    format$post_processor <- function(metadata, input_file, output_file, clean, verbose) {
+  post <- format$post_processor
 
+  format$post_processor <- function(metadata, input_file, output_file, clean, verbose) {
+
+    if (is.function(post)) output_file <- post(metadata, input_file, output_file, clean, verbose)
+
+    if (html_preview) {
       css <- pkg_file_arg(
         "rmarkdown/templates/github_document/resources/github.css")
       # provide a preview that looks like github
@@ -76,7 +116,8 @@ github_document <- function(toc = FALSE,
         "--template", pkg_file_arg(
           "rmarkdown/templates/github_document/resources/preview.html"),
         "--variable", paste0("github-markdown-css:", css),
-        if (pandoc2) c("--metadata", "pagetitle=PREVIEW")  # HTML5 requirement
+        if (pandoc2) c("--metadata", "pagetitle=PREVIEW"),  # HTML5 requirement
+        if (!is.null(math_method)) math$args
       )
 
       # run pandoc
@@ -99,8 +140,9 @@ github_document <- function(toc = FALSE,
 
       if (verbose) message("\nPreview created: ", preview_file)
 
-      output_file
     }
+
+    output_file
   }
 
   format  # return format
