@@ -1,29 +1,33 @@
 #' Convert to an HTML vignette
 #'
-#' A HTML vignette is a lightweight alternative to \code{\link{html_document}}
+#' A HTML vignette is a lightweight alternative to [html_document()]
 #' suitable for inclusion in packages to be released to CRAN. It reduces the
 #' size of a basic vignette from 100k to around 10k.
 #'
-#' Compared to \code{html_document}, it:
+#' Compared to [html_document()], it:
 #'
-#' \itemize{
-#'   \item never uses retina figures
-#'   \item never uses a theme
-#'   \item has a smaller default figure size
-#'   \item uses a custom css stylesheet
-#'  }
+#' * never uses retina figures
+#' * never uses a theme
+#' * has a smaller default figure size
+#' * uses a custom css stylesheet
 #'
-#' See the \href{https://bookdown.org/yihui/rmarkdown/r-package-vignette.html}{online
-#' documentation} for additional details on using the \code{html_vignette} format.
+#' See the [online
+#' documentation](https://bookdown.org/yihui/rmarkdown/r-package-vignette.html)
+#' for additional details on using the `html_vignette()` format.
 #' @inheritParams html_document
 #' @param highlight,... Additional arguments passed to
-#'   \code{\link{html_document}}. Please note that \code{theme} and
-#'   \code{fig_retina} are hard-coded. Setting any of those will yield an error.
+#'   [html_document()]. Please note that `theme` and
+#'   `fig_retina` are hard-coded. Setting any of those will yield an error.
 #' @param css One or more css files to include.
 #' @param readme Use this vignette as the package README.md file (i.e. render
 #'   it as README.md to the package root). Note that if there are image files
-#'   within your vignette you should be sure to add README_files to .Rbuildignore
-#' @return R Markdown output format to pass to \code{\link{render}}
+#'   within your vignette you should be sure to add \file{README_files} to \file{.Rbuildignore}.
+#' @param tabset Opt-in tabbed-sections feature inspired by [html_document()].
+#'   See section "Tabbed Sections" for the detail.
+#'   This feature also allows navigation to the tab from table of contents and URL.
+#' @inheritSection html_document Tabbed Sections
+#' @return R Markdown output format to pass to [render()]
+#' @md
 #' @export
 html_vignette <- function(fig_width = 3,
                           fig_height = 3,
@@ -34,6 +38,8 @@ html_vignette <- function(fig_width = 3,
                           keep_md = FALSE,
                           readme = FALSE,
                           self_contained = TRUE,
+                          tabset = FALSE,
+                          extra_dependencies = NULL,
                           ...) {
 
   if (is.null(css)) {
@@ -41,6 +47,10 @@ html_vignette <- function(fig_width = 3,
       "vignette.css", package = "rmarkdown")
   }
 
+  if (tabset) {
+    extra_dependencies <- append(extra_dependencies, list(html_dependency_tabset()))
+  }
+
   pre_knit <- function(input, ...) {
     if (readme) {
       rmarkdown::render(input,
@@ -73,6 +83,7 @@ html_vignette <- function(fig_width = 3,
                                 theme = NULL,
                                 highlight = highlight,
                                 self_contained = self_contained,
+                                extra_dependencies = extra_dependencies,
                                 ...)
   )
 }
