@@ -66,12 +66,17 @@
 run <- function(file = "index.Rmd", dir = dirname(file), default_file = NULL,
                 auto_reload = TRUE, shiny_args = NULL, render_args = NULL) {
 
+  # if file is missing and there is an index.qmd (and no index.Rmd) then use that
+  if (missing(file) && !file.exists("index.Rmd") && file.exists("index.qmd"))
+    file <- "index.qmd"
+
   # if the file argument is missing then substitute ui.Rmd if it exists
   # (and index.Rmd does not exist)
   if (missing(file) && missing(default_file)) {
-    if (!file.exists(file.path(dir, "index.Rmd")) &&
-        file.exists(file.path(dir, "ui.Rmd"))) {
-      file <- file.path(dir, "ui.Rmd")
+    if (!any(file.exists(file.path(dir, paste0("index.", c("qmd", "Rmd"))))) &&
+        any(file.exists(file.path(dir, paste0("ui.", c("qmd", "Rmd")))))) {
+      uiRmd = file.path(dir, "ui.Rmd")
+      file <- ifelse(file.exists(uiRmd), uiRmd, file.path(dir, "ui.qmd"))
     }
   }
 
@@ -79,20 +84,20 @@ run <- function(file = "index.Rmd", dir = dirname(file), default_file = NULL,
   # documents which start with a leading underscore (same pattern is used to
   # designate "sub-documents" in R Markdown websites and bookdown)
   if (is.null(default_file)) {
-    allRmds <- list.files(path = dir, pattern = "^[^_].*\\.[Rr][Mm][Dd]$")
+    allRmds <- list.files(path = dir, pattern = "^[^_].*\\.[Rrq][Mm][Dd]$")
     if (length(allRmds) == 1) {
       # just one R Markdown document
       default_file <- allRmds
     } else {
       # more than one: look for an index or ui
-      index <- which(tolower(allRmds) %in% c("index.rmd", "ui.rmd"))
+      index <- which(tolower(allRmds) %in% c("index.rmd", "index.qmd", "ui.rmd", "ui.qmd"))
       if (length(index) > 0) {
         default_file <- allRmds[index[1]]
       } else {
         # look for first one that has runtime: shiny
         for (rmd in allRmds) {
-          runtime <- yaml_front_matter(file.path(dir, rmd))$runtime
-          if (is_shiny(runtime)) {
+          yaml <- yaml_front_matter(file.path(dir, rmd))
+          if (is_shiny(yaml$runtime, yaml$server)) {
             default_file <- rmd
             break
           }
@@ -133,6 +138,7 @@ run <- function(file = "index.Rmd", dir = dirname(file), default_file = NULL,
   target_file <- file %||% file.path(dir, default_file)
   yaml_front <- if (length(target_file)) yaml_front_matter(target_file)
   runtime <- yaml_front$runtime
+  server <- yaml_front$server
   theme <- render_args$output_options$theme
   # Let shiny::getCurrentTheme() know about the yaml's theme, so
   # things like `bslib::bs_themer()` can work with prerendered documents.
@@ -147,7 +153,7 @@ run <- function(file = "index.Rmd", dir = dirname(file), default_file = NULL,
   }
 
   # run using the requested mode
-  if (is_shiny_prerendered(runtime)) {
+  if (is_shiny_prerendered(runtime, server)) {
 
     # get the pre-rendered shiny app
     app <- shiny_prerendered_app(target_file, render_args = render_args)
@@ -166,7 +172,7 @@ run <- function(file = "index.Rmd", dir = dirname(file), default_file = NULL,
     # the Shiny server; handle requests for the root (/) and any R markdown files
     # within
     app <- shiny::shinyApp(ui = rmarkdown_shiny_ui(dir, default_file),
-                           uiPattern = "^/$|^/index\\.html?$|^(/.*\\.[Rr][Mm][Dd])$",
+                           uiPattern = "^/$|^/index\\.html?$|^(/.*\\.[Rrq][Mm][Dd])$",
                            onStart = onStart,
                            server = rmarkdown_shiny_server(
                              dir, default_file, auto_reload, render_args))
@@ -335,7 +341,7 @@ rmarkdown_shiny_ui <- function(dir, file) {
 
     # request must be for an R Markdown or HTML document
     ext <- tolower(xfun::file_ext(req_path))
-    if (!(ext %in% c("rmd", "htm", "html"))) return(NULL)
+    if (!(ext %in% c("rmd", "qmd", "htm", "html"))) return(NULL)
 
     # document must exist
     target_file <- resolve_relative(dir, req_path)
@@ -558,16 +564,25 @@ render_delayed <- function(expr) {
   quoted = TRUE)
 }
 
-is_shiny <- function(runtime) {
-  !is.null(runtime) && grepl('^shiny', runtime)
+is_shiny <- function(runtime, server = NULL) {
+  (!is.null(runtime) && grepl('^shiny', runtime)) ||
+  is_shiny_prerendered(runtime, server)
 }
 
 is_shiny_classic <- function(runtime) {
   identical(runtime, "shiny")
 }
 
-is_shiny_prerendered <- function(runtime) {
-  identical(runtime, "shinyrmd") || identical(runtime, "shiny_prerendered")
+is_shiny_prerendered <- function(runtime, server = NULL) {
+  if (identical(runtime, "shinyrmd") || identical(runtime, "shiny_prerendered")) {
+    TRUE
+  } else if (identical(server, "shiny")) {
+    TRUE
+  } else if (is.list(server) && identical(server[["type"]], "shiny")) {
+    TRUE
+  } else {
+    FALSE
+  }
 }
 
 write_shiny_deps <- function(files_dir,
